@@ -6,6 +6,7 @@
 
 from __future__ import annotations
 
+import logging
 import typing as t
 
 from sqlglot import expressions as exp
@@ -21,10 +22,12 @@ from sqlglot.expressions import (
     Expression as Expression,
     alias_ as alias,
     and_ as and_,
+    cast as cast,
     column as column,
     condition as condition,
     except_ as except_,
     from_ as from_,
+    func as func,
     intersect as intersect,
     maybe_parse as maybe_parse,
     not_ as not_,
@@ -33,6 +36,7 @@ from sqlglot.expressions import (
     subquery as subquery,
     table_ as table,
     to_column as to_column,
+    to_identifier as to_identifier,
     to_table as to_table,
     union as union,
 )
@@ -46,8 +50,16 @@ if t.TYPE_CHECKING:
 
     T = t.TypeVar("T", bound=Expression)
 
+logger = logging.getLogger("sqlglot")
+
+
+try:
+    from sqlglot._version import __version__, __version_tuple__
+except ImportError:
+    logger.error(
+        "Unable to set __version__, run `pip install -e .` or `python setup.py develop` first."
+    )
 
-__version__ = "11.7.0"
 
 pretty = False
 """Whether to format generated SQL by default."""
@@ -178,7 +190,7 @@ def transpile(
     Returns:
         The list of transpiled SQL statements.
     """
-    write = write or read if identity else write
+    write = (read if write is None else write) if identity else write
     return [
         Dialect.get_or_raise(write)().generate(expression, **opts)
         for expression in parse(sql, read, error_level=error_level)
