@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from sqlglot import exp, generator, parser, tokens
+from sqlglot import exp, generator, parser, tokens, transforms
 from sqlglot.dialects.dialect import (
     Dialect,
     arrow_json_extract_scalar_sql,
@@ -11,6 +11,7 @@ from sqlglot.dialects.dialect import (
     min_or_least,
     no_ilike_sql,
     no_paren_current_date_sql,
+    no_pivot_sql,
     no_tablesample_sql,
     no_trycast_sql,
     parse_date_delta_with_interval,
@@ -199,11 +200,6 @@ class MySQL(Dialect):
             ),
         }
 
-        PROPERTY_PARSERS = {
-            **parser.Parser.PROPERTY_PARSERS,  # type: ignore
-            "ENGINE": lambda self: self._parse_property_assignment(exp.EngineProperty),
-        }
-
         STATEMENT_PARSERS = {
             **parser.Parser.STATEMENT_PARSERS,  # type: ignore
             TokenType.SHOW: lambda self: self._parse_show(),
@@ -403,6 +399,8 @@ class MySQL(Dialect):
             exp.Min: min_or_least,
             exp.NullSafeEQ: lambda self, e: self.binary(e, "<=>"),
             exp.NullSafeNEQ: lambda self, e: self.not_sql(self.binary(e, "<=>")),
+            exp.Pivot: no_pivot_sql,
+            exp.Select: transforms.preprocess([transforms.eliminate_distinct_on]),
             exp.StrPosition: strposition_to_locate_sql,
             exp.StrToDate: _str_to_date_sql,
             exp.StrToTime: _str_to_date_sql,
