@@ -25,6 +25,12 @@ class Generator:
         quote_end (str): specifies which ending character to use to delimit quotes. Default: '.
         identifier_start (str): specifies which starting character to use to delimit identifiers. Default: ".
         identifier_end (str): specifies which ending character to use to delimit identifiers. Default: ".
+        bit_start (str): specifies which starting character to use to delimit bit literals. Default: None.
+        bit_end (str): specifies which ending character to use to delimit bit literals. Default: None.
+        hex_start (str): specifies which starting character to use to delimit hex literals. Default: None.
+        hex_end (str): specifies which ending character to use to delimit hex literals. Default: None.
+        byte_start (str): specifies which starting character to use to delimit byte literals. Default: None.
+        byte_end (str): specifies which ending character to use to delimit byte literals. Default: None.
         identify (bool | str): 'always': always quote, 'safe': quote identifiers if they don't contain an upcase, True defaults to always.
         normalize (bool): if set to True all identifiers will lower cased
         string_escape (str): specifies a string escape character. Default: '.
@@ -73,6 +79,7 @@ class Generator:
         exp.OnCommitProperty: lambda self, e: "ON COMMIT PRESERVE ROWS",
         exp.ReturnsProperty: lambda self, e: self.naked_property(e),
         exp.SetProperty: lambda self, e: f"{'MULTI' if e.args.get('multi') else ''}SET",
+        exp.SettingsProperty: lambda self, e: f"SETTINGS{self.seg('')}{(self.expressions(e))}",
         exp.SqlSecurityProperty: lambda self, e: f"SQL SECURITY {'DEFINER' if e.args.get('definer') else 'INVOKER'}",
         exp.TemporaryProperty: lambda self, e: f"{'GLOBAL ' if e.args.get('global_') else ''}TEMPORARY",
         exp.TransientProperty: lambda self, e: "TRANSIENT",
@@ -127,6 +134,12 @@ class Generator:
     # Whether or not limit and fetch are supported (possible values: "ALL", "LIMIT", "FETCH")
     LIMIT_FETCH = "ALL"
 
+    # Whether a table is allowed to be renamed with a db
+    RENAME_TABLE_WITH_DB = True
+
+    # The separator for grouping sets and rollups
+    GROUPINGS_SEP = ","
+
     TYPE_MAPPING = {
         exp.DataType.Type.NCHAR: "CHAR",
         exp.DataType.Type.NVARCHAR: "VARCHAR",
@@ -190,7 +203,9 @@ class Generator:
         exp.MergeBlockRatioProperty: exp.Properties.Location.POST_NAME,
         exp.NoPrimaryIndexProperty: exp.Properties.Location.POST_EXPRESSION,
         exp.OnCommitProperty: exp.Properties.Location.POST_EXPRESSION,
+        exp.Order: exp.Properties.Location.POST_SCHEMA,
         exp.PartitionedByProperty: exp.Properties.Location.POST_WITH,
+        exp.PrimaryKey: exp.Properties.Location.POST_SCHEMA,
         exp.Property: exp.Properties.Location.POST_WITH,
         exp.ReturnsProperty: exp.Properties.Location.POST_SCHEMA,
         exp.RowFormatProperty: exp.Properties.Location.POST_SCHEMA,
@@ -198,6 +213,8 @@ class Generator:
         exp.RowFormatSerdeProperty: exp.Properties.Location.POST_SCHEMA,
         exp.SchemaCommentProperty: exp.Properties.Location.POST_SCHEMA,
         exp.SerdeProperties: exp.Properties.Location.POST_SCHEMA,
+        exp.Set: exp.Properties.Location.POST_SCHEMA,
+        exp.SettingsProperty: exp.Properties.Location.POST_SCHEMA,
         exp.SetProperty: exp.Properties.Location.POST_CREATE,
         exp.SortKeyProperty: exp.Properties.Location.POST_SCHEMA,
         exp.SqlSecurityProperty: exp.Properties.Location.POST_CREATE,
@@ -205,6 +222,7 @@ class Generator:
         exp.TableFormatProperty: exp.Properties.Location.POST_WITH,
         exp.TemporaryProperty: exp.Properties.Location.POST_CREATE,
         exp.TransientProperty: exp.Properties.Location.POST_CREATE,
+        exp.MergeTreeTTL: exp.Properties.Location.POST_SCHEMA,
         exp.VolatileProperty: exp.Properties.Location.POST_CREATE,
         exp.WithDataProperty: exp.Properties.Location.POST_EXPRESSION,
         exp.WithJournalTableProperty: exp.Properties.Location.POST_NAME,
@@ -227,6 +245,12 @@ class Generator:
         "quote_end",
         "identifier_start",
         "identifier_end",
+        "bit_start",
+        "bit_end",
+        "hex_start",
+        "hex_end",
+        "byte_start",
+        "byte_end",
         "identify",
         "normalize",
         "string_escape",
@@ -258,6 +282,12 @@ class Generator:
         quote_end=None,
         identifier_start=None,
         identifier_end=None,
+        bit_start=None,
+        bit_end=None,
+        hex_start=None,
+        hex_end=None,
+        byte_start=None,
+        byte_end=None,
         identify=False,
         normalize=False,
         string_escape=None,
@@ -284,6 +314,12 @@ class Generator:
         self.quote_end = quote_end or "'"
         self.identifier_start = identifier_start or '"'
         self.identifier_end = identifier_end or '"'
+        self.bit_start = bit_start
+        self.bit_end = bit_end
+        self.hex_start = hex_start
+        self.hex_end = hex_end
+        self.byte_start = byte_start
+        self.byte_end = byte_end
         self.identify = identify
         self.normalize = normalize
         self.string_escape = string_escape or "'"
@@ -361,7 +397,7 @@ class Generator:
         expression: t.Optional[exp.Expression] = None,
         comments: t.Optional[t.List[str]] = None,
     ) -> str:
-        comments = (comments or (expression and expression.comments)) if self._comments else None  # type: ignore
+        comments = ((expression and expression.comments) if comments is None else comments) if self._comments else None  # type: ignore
 
         if not comments or isinstance(expression, exp.Binary):
             return sql
@@ -375,7 +411,11 @@ class Generator:
             return sql
 
         if isinstance(expression, self.WITH_SEPARATED_COMMENTS):
-            return f"{comments_sql}{self.sep()}{sql}"
+            return (
+                f"{self.sep()}{comments_sql}{sql}"
+                if sql[0].isspace()
+                else f"{comments_sql}{self.sep()}{sql}"
+            )
 
         return f"{sql} {comments_sql}"
 
@@ -510,12 +550,12 @@ class Generator:
         position = self.sql(expression, "position")
         return f"{position}{this}"
 
-    def columndef_sql(self, expression: exp.ColumnDef) -> str:
+    def columndef_sql(self, expression: exp.ColumnDef, sep: str = " ") -> str:
         column = self.sql(expression, "this")
         kind = self.sql(expression, "kind")
         constraints = self.expressions(expression, key="constraints", sep=" ", flat=True)
         exists = "IF NOT EXISTS " if expression.args.get("exists") else ""
-        kind = f" {kind}" if kind else ""
+        kind = f"{sep}{kind}" if kind else ""
         constraints = f" {constraints}" if constraints else ""
         position = self.sql(expression, "position")
         position = f" {position}" if position else ""
@@ -524,7 +564,7 @@ class Generator:
 
     def columnconstraint_sql(self, expression: exp.ColumnConstraint) -> str:
         this = self.sql(expression, "this")
-        kind_sql = self.sql(expression, "kind")
+        kind_sql = self.sql(expression, "kind").strip()
         return f"CONSTRAINT {this} {kind_sql}" if this else kind_sql
 
     def autoincrementcolumnconstraint_sql(self, _) -> str:
@@ -543,7 +583,9 @@ class Generator:
     ) -> str:
         this = ""
         if expression.this is not None:
-            this = " ALWAYS " if expression.this else " BY DEFAULT "
+            on_null = "ON NULL " if expression.args.get("on_null") else ""
+            this = " ALWAYS " if expression.this else f" BY DEFAULT {on_null}"
+
         start = expression.args.get("start")
         start = f"START WITH {start}" if start else ""
         increment = expression.args.get("increment")
@@ -687,9 +729,23 @@ class Generator:
             " WITH NO SCHEMA BINDING" if expression.args.get("no_schema_binding") else ""
         )
 
-        expression_sql = f"CREATE{modifiers} {kind}{exists_sql} {this}{properties_sql}{expression_sql}{postexpression_props_sql}{index_sql}{no_schema_binding}"
+        clone = self.sql(expression, "clone")
+        clone = f" {clone}" if clone else ""
+
+        expression_sql = f"CREATE{modifiers} {kind}{exists_sql} {this}{properties_sql}{expression_sql}{postexpression_props_sql}{index_sql}{no_schema_binding}{clone}"
         return self.prepend_ctes(expression, expression_sql)
 
+    def clone_sql(self, expression: exp.Clone) -> str:
+        this = self.sql(expression, "this")
+        when = self.sql(expression, "when")
+
+        if when:
+            kind = self.sql(expression, "kind")
+            expr = self.sql(expression, "expression")
+            return f"CLONE {this} {when} ({kind} => {expr})"
+
+        return f"CLONE {this}"
+
     def describe_sql(self, expression: exp.Describe) -> str:
         return f"DESCRIBE {self.sql(expression, 'this')}"
 
@@ -716,13 +772,28 @@ class Generator:
         return f"{alias}{columns}"
 
     def bitstring_sql(self, expression: exp.BitString) -> str:
-        return self.sql(expression, "this")
+        this = self.sql(expression, "this")
+        if self.bit_start:
+            return f"{self.bit_start}{this}{self.bit_end}"
+        return f"{int(this, 2)}"
 
     def hexstring_sql(self, expression: exp.HexString) -> str:
-        return self.sql(expression, "this")
+        this = self.sql(expression, "this")
+        if self.hex_start:
+            return f"{self.hex_start}{this}{self.hex_end}"
+        return f"{int(this, 16)}"
 
     def bytestring_sql(self, expression: exp.ByteString) -> str:
-        return self.sql(expression, "this")
+        this = self.sql(expression, "this")
+        if self.byte_start:
+            return f"{self.byte_start}{this}{self.byte_end}"
+        return this
+
+    def datatypesize_sql(self, expression: exp.DataTypeSize) -> str:
+        this = self.sql(expression, "this")
+        specifier = self.sql(expression, "expression")
+        specifier = f" {specifier}" if specifier else ""
+        return f"{this}{specifier}"
 
     def datatype_sql(self, expression: exp.DataType) -> str:
         type_value = expression.this
@@ -1105,20 +1176,25 @@ class Generator:
 
         alias = self.sql(expression, "alias")
         alias = f"{sep}{alias}" if alias else ""
-        hints = self.expressions(expression, key="hints", sep=", ", flat=True)
+        hints = self.expressions(expression, key="hints", flat=True)
         hints = f" WITH ({hints})" if hints and self.TABLE_HINTS else ""
-        laterals = self.expressions(expression, key="laterals", sep="")
+        pivots = self.expressions(expression, key="pivots", sep=" ", flat=True)
+        pivots = f" {pivots}" if pivots else ""
         joins = self.expressions(expression, key="joins", sep="")
-        pivots = self.expressions(expression, key="pivots", sep="")
+        laterals = self.expressions(expression, key="laterals", sep="")
         system_time = expression.args.get("system_time")
         system_time = f" {self.sql(expression, 'system_time')}" if system_time else ""
 
-        return f"{table}{system_time}{alias}{hints}{laterals}{joins}{pivots}"
+        return f"{table}{system_time}{alias}{hints}{pivots}{joins}{laterals}"
 
-    def tablesample_sql(self, expression: exp.TableSample, seed_prefix: str = "SEED") -> str:
+    def tablesample_sql(
+        self, expression: exp.TableSample, seed_prefix: str = "SEED", sep=" AS "
+    ) -> str:
         if self.alias_post_tablesample and expression.this.alias:
-            this = self.sql(expression.this, "this")
-            alias = f" AS {self.sql(expression.this, 'alias')}"
+            table = expression.this.copy()
+            table.set("alias", None)
+            this = self.sql(table)
+            alias = f"{sep}{self.sql(expression.this, 'alias')}"
         else:
             this = self.sql(expression, "this")
             alias = ""
@@ -1142,14 +1218,13 @@ class Generator:
         return f"{this} {kind} {method}({bucket}{percent}{rows}{size}){seed}{alias}"
 
     def pivot_sql(self, expression: exp.Pivot) -> str:
-        this = self.sql(expression, "this")
         alias = self.sql(expression, "alias")
         alias = f" AS {alias}" if alias else ""
         unpivot = expression.args.get("unpivot")
         direction = "UNPIVOT" if unpivot else "PIVOT"
-        expressions = self.expressions(expression, key="expressions")
+        expressions = self.expressions(expression, flat=True)
         field = self.sql(expression, "field")
-        return f"{this} {direction}({expressions} FOR {field}){alias}"
+        return f"{direction}({expressions} FOR {field}){alias}"
 
     def tuple_sql(self, expression: exp.Tuple) -> str:
         return f"({self.expressions(expression, flat=True)})"
@@ -1183,8 +1258,7 @@ class Generator:
         return f"{self.seg('INTO')}{temporary or unlogged} {self.sql(expression, 'this')}"
 
     def from_sql(self, expression: exp.From) -> str:
-        expressions = self.expressions(expression, flat=True)
-        return f"{self.seg('FROM')} {expressions}"
+        return f"{self.seg('FROM')} {self.sql(expression, 'this')}"
 
     def group_sql(self, expression: exp.Group) -> str:
         group_by = self.op_expressions("GROUP BY", expression)
@@ -1207,10 +1281,16 @@ class Generator:
             rollup_sql = self.expressions(expression, key="rollup", indent=False)
             rollup_sql = f"{self.seg('ROLLUP')} {self.wrap(rollup_sql)}" if rollup_sql else ""
 
-        groupings = csv(grouping_sets, cube_sql, rollup_sql, sep=",")
+        groupings = csv(
+            grouping_sets,
+            cube_sql,
+            rollup_sql,
+            self.seg("WITH TOTALS") if expression.args.get("totals") else "",
+            sep=self.GROUPINGS_SEP,
+        )
 
         if expression.args.get("expressions") and groupings:
-            group_by = f"{group_by},"
+            group_by = f"{group_by}{self.GROUPINGS_SEP}"
 
         return f"{group_by}{groupings}"
 
@@ -1219,18 +1299,16 @@ class Generator:
         return f"{self.seg('HAVING')}{self.sep()}{this}"
 
     def join_sql(self, expression: exp.Join) -> str:
-        op_sql = self.seg(
-            " ".join(
-                op
-                for op in (
-                    "NATURAL" if expression.args.get("natural") else None,
-                    expression.side,
-                    expression.kind,
-                    expression.hint if self.JOIN_HINTS else None,
-                    "JOIN",
-                )
-                if op
+        op_sql = " ".join(
+            op
+            for op in (
+                "NATURAL" if expression.args.get("natural") else None,
+                "GLOBAL" if expression.args.get("global") else None,
+                expression.side,
+                expression.kind,
+                expression.hint if self.JOIN_HINTS else None,
             )
+            if op
         )
         on_sql = self.sql(expression, "on")
         using = expression.args.get("using")
@@ -1238,6 +1316,8 @@ class Generator:
         if not on_sql and using:
             on_sql = csv(*(self.sql(column) for column in using))
 
+        this_sql = self.sql(expression, "this")
+
         if on_sql:
             on_sql = self.indent(on_sql, skip_first=True)
             space = self.seg(" " * self.pad) if self.pretty else " "
@@ -1245,10 +1325,11 @@ class Generator:
                 on_sql = f"{space}USING ({on_sql})"
             else:
                 on_sql = f"{space}ON {on_sql}"
+        elif not op_sql:
+            return f", {this_sql}"
 
-        expression_sql = self.sql(expression, "expression")
-        this_sql = self.sql(expression, "this")
-        return f"{expression_sql}{op_sql} {this_sql}{on_sql}"
+        op_sql = f"{op_sql} JOIN" if op_sql else "JOIN"
+        return f"{self.seg(op_sql)} {this_sql}{on_sql}"
 
     def lambda_sql(self, expression: exp.Lambda, arrow_sep: str = "->") -> str:
         args = self.expressions(expression, flat=True)
@@ -1301,12 +1382,22 @@ class Generator:
         return f"PRAGMA {self.sql(expression, 'this')}"
 
     def lock_sql(self, expression: exp.Lock) -> str:
-        if self.LOCKING_READS_SUPPORTED:
-            lock_type = "UPDATE" if expression.args["update"] else "SHARE"
-            return self.seg(f"FOR {lock_type}")
+        if not self.LOCKING_READS_SUPPORTED:
+            self.unsupported("Locking reads using 'FOR UPDATE/SHARE' are not supported")
+            return ""
 
-        self.unsupported("Locking reads using 'FOR UPDATE/SHARE' are not supported")
-        return ""
+        lock_type = "FOR UPDATE" if expression.args["update"] else "FOR SHARE"
+        expressions = self.expressions(expression, flat=True)
+        expressions = f" OF {expressions}" if expressions else ""
+        wait = expression.args.get("wait")
+
+        if wait is not None:
+            if isinstance(wait, exp.Literal):
+                wait = f" WAIT {self.sql(wait)}"
+            else:
+                wait = " NOWAIT" if wait else " SKIP LOCKED"
+
+        return f"{lock_type}{expressions}{wait or ''}"
 
     def literal_sql(self, expression: exp.Literal) -> str:
         text = expression.this or ""
@@ -1425,38 +1516,44 @@ class Generator:
 
         return csv(
             *sqls,
-            *[self.sql(sql) for sql in expression.args.get("joins") or []],
+            *[self.sql(join) for join in expression.args.get("joins") or []],
             self.sql(expression, "match"),
-            *[self.sql(sql) for sql in expression.args.get("laterals") or []],
+            *[self.sql(lateral) for lateral in expression.args.get("laterals") or []],
             self.sql(expression, "where"),
             self.sql(expression, "group"),
             self.sql(expression, "having"),
+            *self.after_having_modifiers(expression),
+            self.sql(expression, "order"),
+            self.sql(expression, "offset") if fetch else self.sql(limit),
+            self.sql(limit) if fetch else self.sql(expression, "offset"),
+            *self.after_limit_modifiers(expression),
+            sep="",
+        )
+
+    def after_having_modifiers(self, expression):
+        return [
             self.sql(expression, "qualify"),
             self.seg("WINDOW ") + self.expressions(expression, key="windows", flat=True)
             if expression.args.get("windows")
             else "",
-            self.sql(expression, "distribute"),
-            self.sql(expression, "sort"),
-            self.sql(expression, "cluster"),
-            self.sql(expression, "order"),
-            self.sql(expression, "offset") if fetch else self.sql(limit),
-            self.sql(limit) if fetch else self.sql(expression, "offset"),
-            self.sql(expression, "lock"),
-            self.sql(expression, "sample"),
-            sep="",
-        )
+        ]
+
+    def after_limit_modifiers(self, expression):
+        locks = self.expressions(expression, key="locks", sep=" ")
+        locks = f" {locks}" if locks else ""
+        return [locks, self.sql(expression, "sample")]
 
     def select_sql(self, expression: exp.Select) -> str:
-        kind = expression.args.get("kind")
-        kind = f" AS {kind}" if kind else ""
         hint = self.sql(expression, "hint")
         distinct = self.sql(expression, "distinct")
         distinct = f" {distinct}" if distinct else ""
+        kind = expression.args.get("kind")
+        kind = f" AS {kind}" if kind else ""
         expressions = self.expressions(expression)
         expressions = f"{self.sep()}{expressions}" if expressions else expressions
         sql = self.query_modifiers(
             expression,
-            f"SELECT{kind}{hint}{distinct}{expressions}",
+            f"SELECT{hint}{distinct}{kind}{expressions}",
             self.sql(expression, "into", comment=False),
             self.sql(expression, "from", comment=False),
         )
@@ -1475,9 +1572,6 @@ class Generator:
         replace = f"{self.seg(self.STAR_MAPPING['replace'])} ({replace})" if replace else ""
         return f"*{except_}{replace}"
 
-    def structkwarg_sql(self, expression: exp.StructKwarg) -> str:
-        return f"{self.sql(expression, 'this')} {self.sql(expression, 'expression')}"
-
     def parameter_sql(self, expression: exp.Parameter) -> str:
         this = self.sql(expression, "this")
         this = f"{{{this}}}" if expression.args.get("wrapped") else f"{this}"
@@ -1497,13 +1591,10 @@ class Generator:
         alias = self.sql(expression, "alias")
         alias = f"{sep}{alias}" if alias else ""
 
-        sql = self.query_modifiers(
-            expression,
-            self.wrap(expression),
-            alias,
-            self.expressions(expression, key="pivots", sep=" "),
-        )
+        pivots = self.expressions(expression, key="pivots", sep=" ", flat=True)
+        pivots = f" {pivots}" if pivots else ""
 
+        sql = self.query_modifiers(expression, self.wrap(expression), alias, pivots)
         return self.prepend_ctes(expression, sql)
 
     def qualify_sql(self, expression: exp.Qualify) -> str:
@@ -1550,7 +1641,7 @@ class Generator:
         partition_sql = partition + " " if partition and order else partition
 
         spec = expression.args.get("spec")
-        spec_sql = " " + self.window_spec_sql(spec) if spec else ""
+        spec_sql = " " + self.windowspec_sql(spec) if spec else ""
 
         alias = self.sql(expression, "alias")
         over = self.sql(expression, "over") or "OVER"
@@ -1572,7 +1663,7 @@ class Generator:
         partition = self.expressions(expression, key="partition_by", flat=True)
         return f"PARTITION BY {partition}" if partition else ""
 
-    def window_spec_sql(self, expression: exp.WindowSpec) -> str:
+    def windowspec_sql(self, expression: exp.WindowSpec) -> str:
         kind = self.sql(expression, "kind")
         start = csv(self.sql(expression, "start"), self.sql(expression, "start_side"), sep=" ")
         end = (
@@ -1713,6 +1804,26 @@ class Generator:
         encoding = f" ENCODING {encoding}" if encoding else ""
         return f"JSON_OBJECT({expressions}{null_handling}{unique_keys}{return_type}{format_json}{encoding})"
 
+    def openjsoncolumndef_sql(self, expression: exp.OpenJSONColumnDef) -> str:
+        this = self.sql(expression, "this")
+        kind = self.sql(expression, "kind")
+        path = self.sql(expression, "path")
+        path = f" {path}" if path else ""
+        as_json = " AS JSON" if expression.args.get("as_json") else ""
+        return f"{this} {kind}{path}{as_json}"
+
+    def openjson_sql(self, expression: exp.OpenJSON) -> str:
+        this = self.sql(expression, "this")
+        path = self.sql(expression, "path")
+        path = f", {path}" if path else ""
+        expressions = self.expressions(expression)
+        with_ = (
+            f" WITH ({self.seg(self.indent(expressions), sep='')}{self.seg(')', sep='')}"
+            if expressions
+            else ""
+        )
+        return f"OPENJSON({this}{path}){with_}"
+
     def in_sql(self, expression: exp.In) -> str:
         query = expression.args.get("query")
         unnest = expression.args.get("unnest")
@@ -1741,7 +1852,7 @@ class Generator:
 
         if self.SINGLE_STRING_INTERVAL:
             this = expression.this.name if expression.this else ""
-            return f"INTERVAL '{this}{unit}'"
+            return f"INTERVAL '{this}{unit}'" if this else f"INTERVAL{unit}"
 
         this = self.sql(expression, "this")
         if this:
@@ -1806,7 +1917,7 @@ class Generator:
             return self.binary(expression, op)
 
         sqls = tuple(
-            self.maybe_comment(self.sql(e), e, e.parent.comments) if i != 1 else self.sql(e)
+            self.maybe_comment(self.sql(e), e, e.parent.comments or []) if i != 1 else self.sql(e)
             for i, e in enumerate(expression.flatten(unnest=False))
         )
 
@@ -1851,6 +1962,28 @@ class Generator:
         expression_sql = self.sql(expression, "expression")
         return f"COMMENT{exists_sql}ON {kind} {this} IS {expression_sql}"
 
+    def mergetreettlaction_sql(self, expression: exp.MergeTreeTTLAction) -> str:
+        this = self.sql(expression, "this")
+        delete = " DELETE" if expression.args.get("delete") else ""
+        recompress = self.sql(expression, "recompress")
+        recompress = f" RECOMPRESS {recompress}" if recompress else ""
+        to_disk = self.sql(expression, "to_disk")
+        to_disk = f" TO DISK {to_disk}" if to_disk else ""
+        to_volume = self.sql(expression, "to_volume")
+        to_volume = f" TO VOLUME {to_volume}" if to_volume else ""
+        return f"{this}{delete}{recompress}{to_disk}{to_volume}"
+
+    def mergetreettl_sql(self, expression: exp.MergeTreeTTL) -> str:
+        where = self.sql(expression, "where")
+        group = self.sql(expression, "group")
+        aggregates = self.expressions(expression, key="aggregates")
+        aggregates = self.seg("SET") + self.seg(aggregates) if aggregates else ""
+
+        if not (where or group or aggregates) and len(expression.expressions) == 1:
+            return f"TTL {self.expressions(expression, flat=True)}"
+
+        return f"TTL{self.seg(self.expressions(expression))}{where}{group}{aggregates}"
+
     def transaction_sql(self, expression: exp.Transaction) -> str:
         return "BEGIN"
 
@@ -1887,6 +2020,11 @@ class Generator:
         return f"ALTER COLUMN {this} DROP DEFAULT"
 
     def renametable_sql(self, expression: exp.RenameTable) -> str:
+        if not self.RENAME_TABLE_WITH_DB:
+            # Remove db from tables
+            expression = expression.transform(
+                lambda n: exp.table_(n.this) if isinstance(n, exp.Table) else n
+            )
         this = self.sql(expression, "this")
         return f"RENAME TO {this}"
 
