@@ -1,13 +1,21 @@
+from __future__ import annotations
+
 import itertools
 import typing as t
 
 from sqlglot import alias, exp
 from sqlglot.errors import OptimizeError
-from sqlglot.optimizer.scope import Scope, traverse_scope
-from sqlglot.schema import ensure_schema
+from sqlglot.helper import seq_get
+from sqlglot.optimizer.scope import Scope, traverse_scope, walk_in_scope
+from sqlglot.schema import Schema, ensure_schema
 
 
-def qualify_columns(expression, schema):
+def qualify_columns(
+    expression: exp.Expression,
+    schema: dict | Schema,
+    expand_alias_refs: bool = True,
+    infer_schema: t.Optional[bool] = None,
+) -> exp.Expression:
     """
     Rewrite sqlglot AST to have fully qualified columns.
 
@@ -19,23 +27,33 @@ def qualify_columns(expression, schema):
         'SELECT tbl.col AS col FROM tbl'
 
     Args:
-        expression (sqlglot.Expression): expression to qualify
-        schema (dict|sqlglot.optimizer.Schema): Database schema
+        expression: expression to qualify
+        schema: Database schema
+        expand_alias_refs: whether or not to expand references to aliases
+        infer_schema: whether or not to infer the schema if missing
     Returns:
         sqlglot.Expression: qualified expression
     """
     schema = ensure_schema(schema)
+    infer_schema = schema.empty if infer_schema is None else infer_schema
 
     for scope in traverse_scope(expression):
-        resolver = Resolver(scope, schema)
+        resolver = Resolver(scope, schema, infer_schema=infer_schema)
         _pop_table_column_aliases(scope.ctes)
         _pop_table_column_aliases(scope.derived_tables)
         using_column_tables = _expand_using(scope, resolver)
+
+        if schema.empty and expand_alias_refs:
+            _expand_alias_refs(scope, resolver)
+
         _qualify_columns(scope, resolver)
+
+        if not schema.empty and expand_alias_refs:
+            _expand_alias_refs(scope, resolver)
+
         if not isinstance(scope.expression, exp.UDTF):
             _expand_stars(scope, resolver, using_column_tables)
             _qualify_outputs(scope)
-        _expand_alias_refs(scope, resolver)
         _expand_group_by(scope, resolver)
         _expand_order_by(scope)
 
@@ -48,9 +66,11 @@ def validate_qualify_columns(expression):
     for scope in traverse_scope(expression):
         if isinstance(scope.expression, exp.Select):
             unqualified_columns.extend(scope.unqualified_columns)
-            if scope.external_columns and not scope.is_correlated_subquery:
+            if scope.external_columns and not scope.is_correlated_subquery and not scope.pivots:
                 column = scope.external_columns[0]
-                raise OptimizeError(f"Unknown table: '{column.table}' for column '{column}'")
+                raise OptimizeError(
+                    f"""Column '{column}' could not be resolved{f" for table: '{column.table}'" if column.table else ''}"""
+                )
 
     if unqualified_columns:
         raise OptimizeError(f"Ambiguous columns: {unqualified_columns}")
@@ -124,7 +144,7 @@ def _expand_using(scope, resolver):
                 tables[join_table] = None
 
         join.args.pop("using")
-        join.set("on", exp.and_(*conditions))
+        join.set("on", exp.and_(*conditions, copy=False))
 
     if column_tables:
         for column in scope.columns:
@@ -135,52 +155,47 @@ def _expand_using(scope, resolver):
 
                 # Ensure selects keep their output name
                 if isinstance(column.parent, exp.Select):
-                    replacement = exp.alias_(replacement, alias=column.name)
+                    replacement = alias(replacement, alias=column.name, copy=False)
 
                 scope.replace(column, replacement)
 
     return column_tables
 
 
-def _expand_alias_refs(scope, resolver):
-    selects = {}
+def _expand_alias_refs(scope: Scope, resolver: Resolver) -> None:
+    expression = scope.expression
 
-    # Replace references to select aliases
-    def transform(node, source_first=True):
-        if isinstance(node, exp.Column) and not node.table:
-            table = resolver.get_table(node.name)
+    if not isinstance(expression, exp.Select):
+        return
 
-            # Source columns get priority over select aliases
-            if source_first and table:
-                node.set("table", table)
-                return node
+    alias_to_expression: t.Dict[str, exp.Expression] = {}
 
-            if not selects:
-                for s in scope.selects:
-                    selects[s.alias_or_name] = s
-            select = selects.get(node.name)
-
-            if select:
-                scope.clear_cache()
-                if isinstance(select, exp.Alias):
-                    select = select.this
-                return select.copy()
-
-            node.set("table", table)
-        elif isinstance(node, exp.Expression) and not isinstance(node, exp.Subqueryable):
-            exp.replace_children(node, transform, source_first)
-
-        return node
-
-    for select in scope.expression.selects:
-        transform(select)
-
-    for modifier, source_first in (
-        ("where", True),
-        ("group", True),
-        ("having", False),
+    def replace_columns(
+        node: t.Optional[exp.Expression], expand: bool = True, resolve_agg: bool = False
     ):
-        transform(scope.expression.args.get(modifier), source_first=source_first)
+        if not node:
+            return
+
+        for column, *_ in walk_in_scope(node):
+            if not isinstance(column, exp.Column):
+                continue
+            table = resolver.get_table(column.name) if resolve_agg and not column.table else None
+            if table and column.find_ancestor(exp.AggFunc):
+                column.set("table", table)
+            elif expand and not column.table and column.name in alias_to_expression:
+                column.replace(alias_to_expression[column.name].copy())
+
+    for projection in scope.selects:
+        replace_columns(projection)
+
+        if isinstance(projection, exp.Alias):
+            alias_to_expression[projection.alias] = projection.this
+
+    replace_columns(expression.args.get("where"))
+    replace_columns(expression.args.get("group"))
+    replace_columns(expression.args.get("having"), resolve_agg=True)
+    replace_columns(expression.args.get("order"), expand=False, resolve_agg=True)
+    scope.clear_cache()
 
 
 def _expand_group_by(scope, resolver):
@@ -235,12 +250,20 @@ def _qualify_columns(scope, resolver):
                 raise OptimizeError(f"Unknown column: {column_name}")
 
         if not column_table:
+            if scope.pivots and not column.find_ancestor(exp.Pivot):
+                # If the column is under the Pivot expression, we need to qualify it
+                # using the name of the pivoted source instead of the pivot's alias
+                column.set("table", exp.to_identifier(scope.pivots[0].alias))
+                continue
+
             column_table = resolver.get_table(column_name)
 
             # column_table can be a '' because bigquery unnest has no table alias
             if column_table:
                 column.set("table", column_table)
-        elif column_table not in scope.sources:
+        elif column_table not in scope.sources and (
+            not scope.parent or column_table not in scope.parent.sources
+        ):
             # structs are used like tables (e.g. "struct"."field"), so they need to be qualified
             # separately and represented as dot(dot(...(<table>.<column>, field1), field2, ...))
 
@@ -256,38 +279,12 @@ def _qualify_columns(scope, resolver):
             if column_table:
                 column.replace(exp.Dot.build([exp.column(root, table=column_table), *parts]))
 
-    columns_missing_from_scope = []
-
-    # Determine whether each reference in the order by clause is to a column or an alias.
-    order = scope.expression.args.get("order")
-
-    if order:
-        for ordered in order.expressions:
-            for column in ordered.find_all(exp.Column):
-                if (
-                    not column.table
-                    and column.parent is not ordered
-                    and column.name in resolver.all_columns
-                ):
-                    columns_missing_from_scope.append(column)
-
-    # Determine whether each reference in the having clause is to a column or an alias.
-    having = scope.expression.args.get("having")
-
-    if having:
-        for column in having.find_all(exp.Column):
-            if (
-                not column.table
-                and column.find_ancestor(exp.AggFunc)
-                and column.name in resolver.all_columns
-            ):
-                columns_missing_from_scope.append(column)
-
-    for column in columns_missing_from_scope:
-        column_table = resolver.get_table(column.name)
-
-        if column_table:
-            column.set("table", column_table)
+    for pivot in scope.pivots:
+        for column in pivot.find_all(exp.Column):
+            if not column.table and column.name in resolver.all_columns:
+                column_table = resolver.get_table(column.name)
+                if column_table:
+                    column.set("table", column_table)
 
 
 def _expand_stars(scope, resolver, using_column_tables):
@@ -298,6 +295,19 @@ def _expand_stars(scope, resolver, using_column_tables):
     replace_columns = {}
     coalesced_columns = set()
 
+    # TODO: handle optimization of multiple PIVOTs (and possibly UNPIVOTs) in the future
+    pivot_columns = None
+    pivot_output_columns = None
+    pivot = seq_get(scope.pivots, 0)
+
+    has_pivoted_source = pivot and not pivot.args.get("unpivot")
+    if has_pivoted_source:
+        pivot_columns = set(col.output_name for col in pivot.find_all(exp.Column))
+
+        pivot_output_columns = [col.output_name for col in pivot.args.get("columns", [])]
+        if not pivot_output_columns:
+            pivot_output_columns = [col.alias_or_name for col in pivot.expressions]
+
     for expression in scope.selects:
         if isinstance(expression, exp.Star):
             tables = list(scope.selected_sources)
@@ -314,9 +324,18 @@ def _expand_stars(scope, resolver, using_column_tables):
         for table in tables:
             if table not in scope.sources:
                 raise OptimizeError(f"Unknown table: {table}")
+
             columns = resolver.get_source_columns(table, only_visible=True)
 
             if columns and "*" not in columns:
+                if has_pivoted_source:
+                    implicit_columns = [col for col in columns if col not in pivot_columns]
+                    new_selections.extend(
+                        exp.alias_(exp.column(name, table=pivot.alias), name, copy=False)
+                        for name in implicit_columns + pivot_output_columns
+                    )
+                    continue
+
                 table_id = id(table)
                 for name in columns:
                     if name in using_column_tables and table in using_column_tables[name]:
@@ -328,16 +347,21 @@ def _expand_stars(scope, resolver, using_column_tables):
                         coalesce = [exp.column(name, table=table) for table in tables]
 
                         new_selections.append(
-                            exp.alias_(
-                                exp.Coalesce(this=coalesce[0], expressions=coalesce[1:]), alias=name
+                            alias(
+                                exp.Coalesce(this=coalesce[0], expressions=coalesce[1:]),
+                                alias=name,
+                                copy=False,
                             )
                         )
                     elif name not in except_columns.get(table_id, set()):
                         alias_ = replace_columns.get(table_id, {}).get(name, name)
-                        column = exp.column(name, table)
-                        new_selections.append(alias(column, alias_) if alias_ != name else column)
+                        column = exp.column(name, table=table)
+                        new_selections.append(
+                            alias(column, alias_, copy=False) if alias_ != name else column
+                        )
             else:
                 return
+
     scope.expression.set("expressions", new_selections)
 
 
@@ -376,10 +400,13 @@ def _qualify_outputs(scope):
             if not selection.output_name:
                 selection.set("alias", exp.TableAlias(this=exp.to_identifier(f"_col_{i}")))
         elif not isinstance(selection, exp.Alias) and not selection.is_star:
-            alias_ = alias(exp.column(""), alias=selection.output_name or f"_col_{i}")
-            alias_.set("this", selection)
-            selection = alias_
-
+            selection = alias(
+                selection,
+                alias=selection.output_name or f"_col_{i}",
+                quoted=True
+                if isinstance(selection, exp.Column) and selection.this.quoted
+                else None,
+            )
         if aliased_column:
             selection.set("alias", exp.to_identifier(aliased_column))
 
@@ -395,12 +422,13 @@ class Resolver:
     This is a class so we can lazily load some things and easily share them across functions.
     """
 
-    def __init__(self, scope, schema):
+    def __init__(self, scope, schema, infer_schema: bool = True):
         self.scope = scope
         self.schema = schema
         self._source_columns = None
-        self._unambiguous_columns = None
+        self._unambiguous_columns: t.Optional[t.Dict[str, str]] = None
         self._all_columns = None
+        self._infer_schema = infer_schema
 
     def get_table(self, column_name: str) -> t.Optional[exp.Identifier]:
         """
@@ -418,7 +446,7 @@ class Resolver:
 
         table_name = self._unambiguous_columns.get(column_name)
 
-        if not table_name:
+        if not table_name and self._infer_schema:
             sources_without_schema = tuple(
                 source
                 for source, columns in self._get_all_source_columns().items()
@@ -438,7 +466,7 @@ class Resolver:
 
         node_alias = node.args.get("alias")
         if node_alias:
-            return node_alias.this
+            return exp.to_identifier(node_alias.this)
 
         return exp.to_identifier(
             table_name, quoted=node.this.quoted if isinstance(node, exp.Table) else None
