@@ -60,6 +60,7 @@ def rewrite_between(expression: exp.Expression) -> exp.Expression:
         return exp.and_(
             exp.GTE(this=expression.this.copy(), expression=expression.args["low"]),
             exp.LTE(this=expression.this.copy(), expression=expression.args["high"]),
+            copy=False,
         )
     return expression
 
@@ -76,9 +77,17 @@ def simplify_not(expression):
         if isinstance(expression.this, exp.Paren):
             condition = expression.this.unnest()
             if isinstance(condition, exp.And):
-                return exp.or_(exp.not_(condition.left), exp.not_(condition.right))
+                return exp.or_(
+                    exp.not_(condition.left, copy=False),
+                    exp.not_(condition.right, copy=False),
+                    copy=False,
+                )
             if isinstance(condition, exp.Or):
-                return exp.and_(exp.not_(condition.left), exp.not_(condition.right))
+                return exp.and_(
+                    exp.not_(condition.left, copy=False),
+                    exp.not_(condition.right, copy=False),
+                    copy=False,
+                )
             if is_null(condition):
                 return exp.null()
         if always_true(expression.this):
@@ -254,12 +263,12 @@ def uniq_sort(expression, cache=None, root=True):
         # A AND C AND B -> A AND B AND C
         for i, (sql, e) in enumerate(arr[1:]):
             if sql < arr[i][0]:
-                expression = result_func(*(e for _, e in sorted(arr)))
+                expression = result_func(*(e for _, e in sorted(arr)), copy=False)
                 break
         else:
             # we didn't have to sort but maybe we need to dedup
             if len(deduped) < len(flattened):
-                expression = result_func(*deduped.values())
+                expression = result_func(*deduped.values(), copy=False)
 
     return expression
 
@@ -379,14 +388,18 @@ def _simplify_binary(expression, a, b):
 
 
 def simplify_parens(expression):
-    if (
-        isinstance(expression, exp.Paren)
-        and not isinstance(expression.this, exp.Select)
-        and (
-            not isinstance(expression.parent, (exp.Condition, exp.Binary))
-            or isinstance(expression.this, exp.Predicate)
-            or not isinstance(expression.this, exp.Binary)
-        )
+    if not isinstance(expression, exp.Paren):
+        return expression
+
+    this = expression.this
+    parent = expression.parent
+
+    if not isinstance(this, exp.Select) and (
+        not isinstance(parent, (exp.Condition, exp.Binary))
+        or isinstance(this, exp.Predicate)
+        or not isinstance(this, exp.Binary)
+        or (isinstance(this, exp.Add) and isinstance(parent, exp.Add))
+        or (isinstance(this, exp.Mul) and isinstance(parent, exp.Mul))
     ):
         return expression.this
     return expression
