@@ -68,6 +68,11 @@ class Schema(abc.ABC):
         """
         raise NotImplementedError
 
+    @property
+    def empty(self) -> bool:
+        """Returns whether or not the schema is empty."""
+        return True
+
 
 class AbstractMappingSchema(t.Generic[T]):
     def __init__(
@@ -80,6 +85,10 @@ class AbstractMappingSchema(t.Generic[T]):
         )
         self._supported_table_args: t.Tuple[str, ...] = tuple()
 
+    @property
+    def empty(self) -> bool:
+        return not self.mapping
+
     def _depth(self) -> int:
         return dict_depth(self.mapping)
 
